from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Taxonomy(_message.Message):
    __slots__ = ("year", "series", "scale", "difficulty", "country", "region", "city")
    class Scale(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_SCALE: _ClassVar[Taxonomy.Scale]
        LOCAL: _ClassVar[Taxonomy.Scale]
        REGIONAL: _ClassVar[Taxonomy.Scale]
        NATIONAL: _ClassVar[Taxonomy.Scale]
        INTERNATIONAL: _ClassVar[Taxonomy.Scale]
    UNKNOWN_SCALE: Taxonomy.Scale
    LOCAL: Taxonomy.Scale
    REGIONAL: Taxonomy.Scale
    NATIONAL: Taxonomy.Scale
    INTERNATIONAL: Taxonomy.Scale
    YEAR_FIELD_NUMBER: _ClassVar[int]
    SERIES_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    year: int
    series: str
    scale: Taxonomy.Scale
    difficulty: int
    country: str
    region: str
    city: str
    def __init__(self, year: _Optional[int] = ..., series: _Optional[str] = ..., scale: _Optional[_Union[Taxonomy.Scale, str]] = ..., difficulty: _Optional[int] = ..., country: _Optional[str] = ..., region: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/variant.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/content/variant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/content/variant.proto\x12\x0e\x65olymp.content\x1a\x18\x65olymp/ecm/content.proto\"\xab\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\r\n\x05title\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\x33 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x11\n\tautomatic\x18\x08 \x01(\x08\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.variant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_VARIANT']._serialized_start=75
  _globals['_VARIANT']._serialized_end=246
  _globals['_VARIANT_EXTRA']._serialized_start=186
  _globals['_VARIANT_EXTRA']._serialized_end=246
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import contest_certification_pb2 as _contest_certification_pb2
from eolymp.judge import contest_environment_pb2 as _contest_environment_pb2
from eolymp.judge import contest_taxonomy_pb2 as _contest_taxonomy_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeEnvironmentInput(_message.Message):
    __slots__ = ("contest_id",)
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DescribeEnvironmentOutput(_message.Message):
    __slots__ = ("environment",)
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    environment: _contest_environment_pb2.Environment
    def __init__(self, environment: _Optional[_Union[_contest_environment_pb2.Environment, _Mapping]] = ...) -> None: ...

class ConfigureEnvironmentInput(_message.Message):
    __slots__ = ("contest_id", "environment")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    environment: _contest_environment_pb2.Environment
    def __init__(self, contest_id: _Optional[str] = ..., environment: _Optional[_Union[_contest_environment_pb2.Environment, _Mapping]] = ...) -> None: ...

class ConfigureEnvironmentOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeCertificationInput(_message.Message):
    __slots__ = ("contest_id",)
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DescribeCertificationOutput(_message.Message):
    __slots__ = ("certification",)
    CERTIFICATION_FIELD_NUMBER: _ClassVar[int]
    certification: _contest_certification_pb2.Certification
    def __init__(self, certification: _Optional[_Union[_contest_certification_pb2.Certification, _Mapping]] = ...) -> None: ...

class ConfigureCertificationInput(_message.Message):
    __slots__ = ("contest_id", "certification")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATION_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    certification: _contest_certification_pb2.Certification
    def __init__(self, contest_id: _Optional[str] = ..., certification: _Optional[_Union[_contest_certification_pb2.Certification, _Mapping]] = ...) -> None: ...

class ConfigureCertificationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeTaxonomyInput(_message.Message):
    __slots__ = ("contest_id",)
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DescribeTaxonomyOutput(_message.Message):
    __slots__ = ("taxonomy",)
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    taxonomy: _contest_taxonomy_pb2.Taxonomy
    def __init__(self, taxonomy: _Optional[_Union[_contest_taxonomy_pb2.Taxonomy, _Mapping]] = ...) -> None: ...

class ConfigureTaxonomyInput(_message.Message):
    __slots__ = ("contest_id", "taxonomy")
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    taxonomy: _contest_taxonomy_pb2.Taxonomy
    def __init__(self, contest_id: _Optional[str] = ..., taxonomy: _Optional[_Union[_contest_taxonomy_pb2.Taxonomy, _Mapping]] = ...) -> None: ...

class ConfigureTaxonomyOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.judge import contest_taxonomy_pb2 as _contest_taxonomy_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contest(_message.Message):
    __slots__ = ("id", "url", "name", "image_url", "starts_at", "starts_in", "ends_at", "ends_in", "duration", "status", "visibility", "join_unofficially", "participation_mode", "require_admission", "allow_pause", "allow_finish_early", "allow_upsolve", "allow_followup", "format", "key", "problem_count", "problem_count_hidden", "participant_count", "participant_count_hidden", "featured_until", "printer_id", "scoreboard", "taxonomy")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[Contest.Patch]
        NAME: _ClassVar[Contest.Patch]
        STARTS_AT: _ClassVar[Contest.Patch]
        ENDS_AT: _ClassVar[Contest.Patch]
        DURATION: _ClassVar[Contest.Patch]
        VISIBILITY: _ClassVar[Contest.Patch]
        JOIN_UNOFFICIALLY: _ClassVar[Contest.Patch]
        REQUIRE_ADMISSION: _ClassVar[Contest.Patch]
        ALLOW_PAUSE: _ClassVar[Contest.Patch]
        ALLOW_FINISH_EARLY: _ClassVar[Contest.Patch]
        ALLOW_UPSOLVE: _ClassVar[Contest.Patch]
        ALLOW_FOLLOWUP: _ClassVar[Contest.Patch]
        PARTICIPATION_MODE: _ClassVar[Contest.Patch]
        FORMAT: _ClassVar[Contest.Patch]
        KEY: _ClassVar[Contest.Patch]
        IMAGE_URL: _ClassVar[Contest.Patch]
        PROBLEM_COUNT_HIDDEN: _ClassVar[Contest.Patch]
        PARTICIPANT_COUNT_HIDDEN: _ClassVar[Contest.Patch]
        FEATURED_UNTIL: _ClassVar[Contest.Patch]
        PRINTER: _ClassVar[Contest.Patch]
        SCOREBOARD: _ClassVar[Contest.Patch]
    ALL: Contest.Patch
    NAME: Contest.Patch
    STARTS_AT: Contest.Patch
    ENDS_AT: Contest.Patch
    DURATION: Contest.Patch
    VISIBILITY: Contest.Patch
    JOIN_UNOFFICIALLY: Contest.Patch
    REQUIRE_ADMISSION: Contest.Patch
    ALLOW_PAUSE: Contest.Patch
    ALLOW_FINISH_EARLY: Contest.Patch
    ALLOW_UPSOLVE: Contest.Patch
    ALLOW_FOLLOWUP: Contest.Patch
    PARTICIPATION_MODE: Contest.Patch
    FORMAT: Contest.Patch
    KEY: Contest.Patch
    IMAGE_URL: Contest.Patch
    PROBLEM_COUNT_HIDDEN: Contest.Patch
    PARTICIPANT_COUNT_HIDDEN: Contest.Patch
    FEATURED_UNTIL: Contest.Patch
    PRINTER: Contest.Patch
    SCOREBOARD: Contest.Patch
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Contest.Extra]
        TAXONOMY: _ClassVar[Contest.Extra]
    UNKNOWN_EXTRA: Contest.Extra
    TAXONOMY: Contest.Extra
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATUS_UNKNOWN: _ClassVar[Contest.Status]
        SCHEDULED: _ClassVar[Contest.Status]
        OPEN: _ClassVar[Contest.Status]
        COMPLETE: _ClassVar[Contest.Status]
        SUSPENDED: _ClassVar[Contest.Status]
        FROZEN: _ClassVar[Contest.Status]
        FINALIZED: _ClassVar[Contest.Status]
    STATUS_UNKNOWN: Contest.Status
    SCHEDULED: Contest.Status
    OPEN: Contest.Status
    COMPLETE: Contest.Status
    SUSPENDED: Contest.Status
    FROZEN: Contest.Status
    FINALIZED: Contest.Status
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VISIBILITY_UNKNOWN: _ClassVar[Contest.Visibility]
        PUBLIC: _ClassVar[Contest.Visibility]
        UNLISTED: _ClassVar[Contest.Visibility]
        PRIVATE: _ClassVar[Contest.Visibility]
    VISIBILITY_UNKNOWN: Contest.Visibility
    PUBLIC: Contest.Visibility
    UNLISTED: Contest.Visibility
    PRIVATE: Contest.Visibility
    class ParticipationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPATION_MODE_UNKNOWN: _ClassVar[Contest.ParticipationMode]
        ONLINE: _ClassVar[Contest.ParticipationMode]
        VIRTUAL: _ClassVar[Contest.ParticipationMode]
    PARTICIPATION_MODE_UNKNOWN: Contest.ParticipationMode
    ONLINE: Contest.ParticipationMode
    VIRTUAL: Contest.ParticipationMode
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FORMAT_UNKNOWN: _ClassVar[Contest.Format]
        IOI: _ClassVar[Contest.Format]
        ICPC: _ClassVar[Contest.Format]
    FORMAT_UNKNOWN: Contest.Format
    IOI: Contest.Format
    ICPC: Contest.Format
    class Scoreboard(_message.Message):
        __slots__ = ("visibility", "freezing_time", "unfreeze_delay", "attempt_penalty", "tie_breaker", "no_spoiler_ui", "share_key")
        class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_VISIBILITY: _ClassVar[Contest.Scoreboard.Visibility]
            INVISIBLE: _ClassVar[Contest.Scoreboard.Visibility]
            INTERNAL: _ClassVar[Contest.Scoreboard.Visibility]
            PUBLIC: _ClassVar[Contest.Scoreboard.Visibility]
        UNKNOWN_VISIBILITY: Contest.Scoreboard.Visibility
        INVISIBLE: Contest.Scoreboard.Visibility
        INTERNAL: Contest.Scoreboard.Visibility
        PUBLIC: Contest.Scoreboard.Visibility
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        FREEZING_TIME_FIELD_NUMBER: _ClassVar[int]
        UNFREEZE_DELAY_FIELD_NUMBER: _ClassVar[int]
        ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        NO_SPOILER_UI_FIELD_NUMBER: _ClassVar[int]
        SHARE_KEY_FIELD_NUMBER: _ClassVar[int]
        visibility: Contest.Scoreboard.Visibility
        freezing_time: int
        unfreeze_delay: int
        attempt_penalty: int
        tie_breaker: str
        no_spoiler_ui: bool
        share_key: str
        def __init__(self, visibility: _Optional[_Union[Contest.Scoreboard.Visibility, str]] = ..., freezing_time: _Optional[int] = ..., unfreeze_delay: _Optional[int] = ..., attempt_penalty: _Optional[int] = ..., tie_breaker: _Optional[str] = ..., no_spoiler_ui: bool = ..., share_key: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    STARTS_AT_FIELD_NUMBER: _ClassVar[int]
    STARTS_IN_FIELD_NUMBER: _ClassVar[int]
    ENDS_AT_FIELD_NUMBER: _ClassVar[int]
    ENDS_IN_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    JOIN_UNOFFICIALLY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_FIELD_NUMBER: _ClassVar[int]
    REQUIRE_ADMISSION_FIELD_NUMBER: _ClassVar[int]
    ALLOW_PAUSE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_FINISH_EARLY_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_FOLLOWUP_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    FEATURED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    name: str
    image_url: str
    starts_at: _timestamp_pb2.Timestamp
    starts_in: int
    ends_at: _timestamp_pb2.Timestamp
    ends_in: int
    duration: int
    status: Contest.Status
    visibility: Contest.Visibility
    join_unofficially: bool
    participation_mode: Contest.ParticipationMode
    require_admission: bool
    allow_pause: bool
    allow_finish_early: bool
    allow_upsolve: bool
    allow_followup: bool
    format: Contest.Format
    key: str
    problem_count: int
    problem_count_hidden: bool
    participant_count: int
    participant_count_hidden: bool
    featured_until: _timestamp_pb2.Timestamp
    printer_id: str
    scoreboard: Contest.Scoreboard
    taxonomy: _contest_taxonomy_pb2.Taxonomy
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., starts_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., starts_in: _Optional[int] = ..., ends_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., ends_in: _Optional[int] = ..., duration: _Optional[int] = ..., status: _Optional[_Union[Contest.Status, str]] = ..., visibility: _Optional[_Union[Contest.Visibility, str]] = ..., join_unofficially: bool = ..., participation_mode: _Optional[_Union[Contest.ParticipationMode, str]] = ..., require_admission: bool = ..., allow_pause: bool = ..., allow_finish_early: bool = ..., allow_upsolve: bool = ..., allow_followup: bool = ..., format: _Optional[_Union[Contest.Format, str]] = ..., key: _Optional[str] = ..., problem_count: _Optional[int] = ..., problem_count_hidden: bool = ..., participant_count: _Optional[int] = ..., participant_count_hidden: bool = ..., featured_until: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., printer_id: _Optional[str] = ..., scoreboard: _Optional[_Union[Contest.Scoreboard, _Mapping]] = ..., taxonomy: _Optional[_Union[_contest_taxonomy_pb2.Taxonomy, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Certification(_message.Message):
    __slots__ = ("enabled", "affiliation", "signers")
    class Signer(_message.Message):
        __slots__ = ("name", "title")
        NAME_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        name: str
        title: str
        def __init__(self, name: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    AFFILIATION_FIELD_NUMBER: _ClassVar[int]
    SIGNERS_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    affiliation: str
    signers: _containers.RepeatedCompositeFieldContainer[Certification.Signer]
    def __init__(self, enabled: bool = ..., affiliation: _Optional[str] = ..., signers: _Optional[_Iterable[_Union[Certification.Signer, _Mapping]]] = ...) -> None: ...



from eolymp.executor import file_pb2 as _file_pb2
from eolymp.executor import interactor_pb2 as _interactor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Interactor(_message.Message):
    __slots__ = ("version_id", "secret", "type", "runtime", "source", "files")
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    version_id: str
    secret: bool
    type: _interactor_pb2.Interactor.Type
    runtime: str
    source: str
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    def __init__(self, version_id: _Optional[str] = ..., secret: bool = ..., type: _Optional[_Union[_interactor_pb2.Interactor.Type, str]] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/script.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/executor/script.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/script.proto\x12\x0f\x65olymp.executor\x1a\x1a\x65olymp/executor/file.proto\"\x89\x01\n\x06Script\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x08 \x01(\t\x12\x12\n\nheader_url\x18\x0b \x01(\t\x12\x12\n\nfooter_url\x18\x0c \x01(\t\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.FileB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.script_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_SCRIPT']._serialized_start=78
  _globals['_SCRIPT']._serialized_end=215
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/contest_environment.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/judge/contest_environment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/judge/contest_environment.proto\x12\x0c\x65olymp.judge\x1a\x1c\x65olymp/runtime/runtime.proto\"8\n\x0b\x45nvironment\x12)\n\x08runtimes\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.RuntimeB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_environment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_ENVIRONMENT']._serialized_start=86
  _globals['_ENVIRONMENT']._serialized_end=142
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/scoreboard_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/ranker/scoreboard_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/ranker/scoreboard_service.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x84\x01\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\x12\x1b\n\x13\x61\x64\x64_default_columns\x18\x02 \x01(\x08\x12\x1f\n\x17\x64uplicate_scoreboard_id\x18\x03 \x01(\t\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdateScoreboardInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.ranker.UpdateScoreboardInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12-\n\nscoreboard\x18\x03 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"E\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x10\n\x0c\x44\x45\x46\x41ULT_SORT\x10\x03\x12\x0e\n\nHISTORICAL\x10\x04\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"y\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"`\n\x15LookupScoreboardInput\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\"G\n\x16LookupScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xd8\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x93\x01\n\x1a\x44\x65scribeScoreboardRowInput\x12\x34\n\x04mode\x18\n \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x0b \x01(\r\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"Y\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"\xd3\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x12\x0c\n\x04sort\x18\x32 \x01(\t\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xb4\x01\n\x10\x45xpressionColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x06string\x18\n \x01(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06number\x18\x0b \x01(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12.\n\x04\x65num\x18\x0c \x01(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x1a\x84\x01\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12G\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x37.eolymp.ranker.ListScoreboardRowsInput.ExpressionColumn\"g\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"\xb4\x02\n\x1bUpdateScoreboardColumnInput\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.ranker.UpdateScoreboardColumnInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x11\n\tcolumn_id\x18\x03 \x01(\t\x12\x30\n\x06\x63olumn\x18\x04 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"x\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\r\n\tPARENT_ID\x10\x01\x12\x07\n\x03KEY\x10\x02\x12\x08\n\x04NAME\x10\x03\x12\x0e\n\nSHORT_NAME\x10\x04\x12\t\n\x05INDEX\x10\x05\x12\x0b\n\x07VISIBLE\x10\x06\x12\x0e\n\nFILTERABLE\x10\x07\x12\x0c\n\x08SORTABLE\x10\x08\"\x1e\n\x1cUpdateScoreboardColumnOutput\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column2\xb0\x15\n\x11ScoreboardService\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\xa9\x01\n\x10LookupScoreboard\x12$.eolymp.ranker.LookupScoreboardInput\x1a%.eolymp.ranker.LookupScoreboardOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x15\"\x13/scoreboards:lookup\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columnsB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.scoreboard_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['CreateScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['CreateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\016\"\014/scoreboards'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['RebuildScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['RebuildScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['LookupScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['LookupScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\025\"\023/scoreboards:lookup'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboards']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboards']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\016\022\014/scoreboards'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardRow']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardRow']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardRows']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardRows']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['AddScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['AddScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardColumns']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardColumns']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _globals['_CREATESCOREBOARDINPUT']._serialized_start=258
  _globals['_CREATESCOREBOARDINPUT']._serialized_end=390
  _globals['_CREATESCOREBOARDOUTPUT']._serialized_start=392
  _globals['_CREATESCOREBOARDOUTPUT']._serialized_end=439
  _globals['_UPDATESCOREBOARDINPUT']._serialized_start=442
  _globals['_UPDATESCOREBOARDINPUT']._serialized_end=665
  _globals['_UPDATESCOREBOARDINPUT_PATCH']._serialized_start=596
  _globals['_UPDATESCOREBOARDINPUT_PATCH']._serialized_end=665
  _globals['_UPDATESCOREBOARDOUTPUT']._serialized_start=667
  _globals['_UPDATESCOREBOARDOUTPUT']._serialized_end=691
  _globals['_REBUILDSCOREBOARDINPUT']._serialized_start=693
  _globals['_REBUILDSCOREBOARDINPUT']._serialized_end=740
  _globals['_REBUILDSCOREBOARDOUTPUT']._serialized_start=742
  _globals['_REBUILDSCOREBOARDOUTPUT']._serialized_end=788
  _globals['_DELETESCOREBOARDINPUT']._serialized_start=790
  _globals['_DELETESCOREBOARDINPUT']._serialized_end=836
  _globals['_DELETESCOREBOARDOUTPUT']._serialized_start=838
  _globals['_DELETESCOREBOARDOUTPUT']._serialized_end=862
  _globals['_DESCRIBESCOREBOARDINPUT']._serialized_start=864
  _globals['_DESCRIBESCOREBOARDINPUT']._serialized_end=985
  _globals['_DESCRIBESCOREBOARDOUTPUT']._serialized_start=987
  _globals['_DESCRIBESCOREBOARDOUTPUT']._serialized_end=1060
  _globals['_LOOKUPSCOREBOARDINPUT']._serialized_start=1062
  _globals['_LOOKUPSCOREBOARDINPUT']._serialized_end=1158
  _globals['_LOOKUPSCOREBOARDOUTPUT']._serialized_start=1160
  _globals['_LOOKUPSCOREBOARDOUTPUT']._serialized_end=1231
  _globals['_LISTSCOREBOARDSINPUT']._serialized_start=1234
  _globals['_LISTSCOREBOARDSINPUT']._serialized_end=1450
  _globals['_LISTSCOREBOARDSINPUT_FILTER']._serialized_start=1398
  _globals['_LISTSCOREBOARDSINPUT_FILTER']._serialized_end=1450
  _globals['_LISTSCOREBOARDSOUTPUT']._serialized_start=1452
  _globals['_LISTSCOREBOARDSOUTPUT']._serialized_end=1532
  _globals['_DESCRIBESCOREBOARDROWINPUT']._serialized_start=1535
  _globals['_DESCRIBESCOREBOARDROWINPUT']._serialized_end=1682
  _globals['_DESCRIBESCOREBOARDROWOUTPUT']._serialized_start=1684
  _globals['_DESCRIBESCOREBOARDROWOUTPUT']._serialized_end=1773
  _globals['_LISTSCOREBOARDROWSINPUT']._serialized_start=1776
  _globals['_LISTSCOREBOARDROWSINPUT']._serialized_end=2371
  _globals['_LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN']._serialized_start=2056
  _globals['_LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN']._serialized_end=2236
  _globals['_LISTSCOREBOARDROWSINPUT_FILTER']._serialized_start=2239
  _globals['_LISTSCOREBOARDROWSINPUT_FILTER']._serialized_end=2371
  _globals['_LISTSCOREBOARDROWSOUTPUT']._serialized_start=2373
  _globals['_LISTSCOREBOARDROWSOUTPUT']._serialized_end=2476
  _globals['_ADDSCOREBOARDCOLUMNINPUT']._serialized_start=2478
  _globals['_ADDSCOREBOARDCOLUMNINPUT']._serialized_end=2577
  _globals['_ADDSCOREBOARDCOLUMNOUTPUT']._serialized_start=2579
  _globals['_ADDSCOREBOARDCOLUMNOUTPUT']._serialized_end=2625
  _globals['_UPDATESCOREBOARDCOLUMNINPUT']._serialized_start=2628
  _globals['_UPDATESCOREBOARDCOLUMNINPUT']._serialized_end=2936
  _globals['_UPDATESCOREBOARDCOLUMNINPUT_PATCH']._serialized_start=2816
  _globals['_UPDATESCOREBOARDCOLUMNINPUT_PATCH']._serialized_end=2936
  _globals['_UPDATESCOREBOARDCOLUMNOUTPUT']._serialized_start=2938
  _globals['_UPDATESCOREBOARDCOLUMNOUTPUT']._serialized_end=2968
  _globals['_DELETESCOREBOARDCOLUMNINPUT']._serialized_start=2970
  _globals['_DELETESCOREBOARDCOLUMNINPUT']._serialized_end=3041
  _globals['_DELETESCOREBOARDCOLUMNOUTPUT']._serialized_start=3043
  _globals['_DELETESCOREBOARDCOLUMNOUTPUT']._serialized_end=3073
  _globals['_DESCRIBESCOREBOARDCOLUMNINPUT']._serialized_start=3075
  _globals['_DESCRIBESCOREBOARDCOLUMNINPUT']._serialized_end=3148
  _globals['_DESCRIBESCOREBOARDCOLUMNOUTPUT']._serialized_start=3150
  _globals['_DESCRIBESCOREBOARDCOLUMNOUTPUT']._serialized_end=3232
  _globals['_LISTSCOREBOARDCOLUMNSINPUT']._serialized_start=3234
  _globals['_LISTSCOREBOARDCOLUMNSINPUT']._serialized_end=3285
  _globals['_LISTSCOREBOARDCOLUMNSOUTPUT']._serialized_start=3287
  _globals['_LISTSCOREBOARDCOLUMNSOUTPUT']._serialized_end=3380
  _globals['_SCOREBOARDSERVICE']._serialized_start=3383
  _globals['_SCOREBOARDSERVICE']._serialized_end=6119
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Assignment(_message.Message):
    __slots__ = ("id", "module_id", "status", "member_id", "group_id", "start_after", "complete_before", "duration", "upsolve")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Assignment.Status]
        UNASSIGNED: _ClassVar[Assignment.Status]
        SCHEDULED: _ClassVar[Assignment.Status]
        READY: _ClassVar[Assignment.Status]
        ACTIVE: _ClassVar[Assignment.Status]
        COMPLETE: _ClassVar[Assignment.Status]
        UPSOLVE: _ClassVar[Assignment.Status]
    UNKNOWN_STATUS: Assignment.Status
    UNASSIGNED: Assignment.Status
    SCHEDULED: Assignment.Status
    READY: Assignment.Status
    ACTIVE: Assignment.Status
    COMPLETE: Assignment.Status
    UPSOLVE: Assignment.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    module_id: str
    status: Assignment.Status
    member_id: str
    group_id: str
    start_after: _timestamp_pb2.Timestamp
    complete_before: _timestamp_pb2.Timestamp
    duration: int
    upsolve: bool
    def __init__(self, id: _Optional[str] = ..., module_id: _Optional[str] = ..., status: _Optional[_Union[Assignment.Status, str]] = ..., member_id: _Optional[str] = ..., group_id: _Optional[str] = ..., start_after: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., upsolve: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/taxonomy/enum_value.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/taxonomy/enum_value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/taxonomy/enum_value.proto\x12\x0f\x65olymp.taxonomy\"\xbf\x01\n\x05Value\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x0c\n\x04\x61\x62\x62r\x18\x05 \x01(\t\x12\r\n\x05image\x18\x06 \x01(\t\x12\x10\n\x08keywords\x18\x04 \x03(\t\x1a\\\n\x0bTranslation\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x61\x62\x62r\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x10\n\x08keywords\x18\x04 \x03(\tB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.enum_value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _globals['_VALUE']._serialized_start=54
  _globals['_VALUE']._serialized_end=245
  _globals['_VALUE_TRANSLATION']._serialized_start=153
  _globals['_VALUE_TRANSLATION']._serialized_end=245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/configuration_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/judge/configuration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import contest_certification_pb2 as eolymp_dot_judge_dot_contest__certification__pb2
from eolymp.judge import contest_environment_pb2 as eolymp_dot_judge_dot_contest__environment__pb2
from eolymp.judge import contest_taxonomy_pb2 as eolymp_dot_judge_dot_contest__taxonomy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/judge/configuration_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a(eolymp/judge/contest_certification.proto\x1a&eolymp/judge/contest_environment.proto\x1a#eolymp/judge/contest_taxonomy.proto\".\n\x18\x44\x65scribeEnvironmentInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"K\n\x19\x44\x65scribeEnvironmentOutput\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Environment\"_\n\x19\x43onfigureEnvironmentInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Environment\"\x1c\n\x1a\x43onfigureEnvironmentOutput\"0\n\x1a\x44\x65scribeCertificationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"Q\n\x1b\x44\x65scribeCertificationOutput\x12\x32\n\rcertification\x18\x02 \x01(\x0b\x32\x1b.eolymp.judge.Certification\"e\n\x1b\x43onfigureCertificationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x32\n\rcertification\x18\x02 \x01(\x0b\x32\x1b.eolymp.judge.Certification\"\x1e\n\x1c\x43onfigureCertificationOutput\"+\n\x15\x44\x65scribeTaxonomyInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"B\n\x16\x44\x65scribeTaxonomyOutput\x12(\n\x08taxonomy\x18\x02 \x01(\x0b\x32\x16.eolymp.judge.Taxonomy\"V\n\x16\x43onfigureTaxonomyInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12(\n\x08taxonomy\x18\x02 \x01(\x0b\x32\x16.eolymp.judge.Taxonomy\"\x19\n\x17\x43onfigureTaxonomyOutput2\x91\t\n\x14\x43onfigurationService\x12\xbc\x01\n\x13\x44\x65scribeEnvironment\x12&.eolymp.judge.DescribeEnvironmentInput\x1a\'.eolymp.judge.DescribeEnvironmentOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02$\"\"/contests/{contest_id}/environment\x12\xbf\x01\n\x14\x43onfigureEnvironment\x12\'.eolymp.judge.ConfigureEnvironmentInput\x1a(.eolymp.judge.ConfigureEnvironmentOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02$\"\"/contests/{contest_id}/environment\x12\xc4\x01\n\x15\x44\x65scribeCertification\x12(.eolymp.judge.DescribeCertificationInput\x1a).eolymp.judge.DescribeCertificationOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/certification\x12\xc7\x01\n\x16\x43onfigureCertification\x12).eolymp.judge.ConfigureCertificationInput\x1a*.eolymp.judge.ConfigureCertificationOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/certification\x12\xb0\x01\n\x10\x44\x65scribeTaxonomy\x12#.eolymp.judge.DescribeTaxonomyInput\x1a$.eolymp.judge.DescribeTaxonomyOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/taxonomy\x12\xb3\x01\n\x11\x43onfigureTaxonomy\x12$.eolymp.judge.ConfigureTaxonomyInput\x1a%.eolymp.judge.ConfigureTaxonomyOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/taxonomyB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.configuration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeEnvironment']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeEnvironment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002$\"\"/contests/{contest_id}/environment'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureEnvironment']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureEnvironment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002$\"\"/contests/{contest_id}/environment'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeCertification']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeCertification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/certification'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureCertification']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureCertification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/certification'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeTaxonomy']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeTaxonomy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/taxonomy'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureTaxonomy']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureTaxonomy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/taxonomy'
  _globals['_DESCRIBEENVIRONMENTINPUT']._serialized_start=276
  _globals['_DESCRIBEENVIRONMENTINPUT']._serialized_end=322
  _globals['_DESCRIBEENVIRONMENTOUTPUT']._serialized_start=324
  _globals['_DESCRIBEENVIRONMENTOUTPUT']._serialized_end=399
  _globals['_CONFIGUREENVIRONMENTINPUT']._serialized_start=401
  _globals['_CONFIGUREENVIRONMENTINPUT']._serialized_end=496
  _globals['_CONFIGUREENVIRONMENTOUTPUT']._serialized_start=498
  _globals['_CONFIGUREENVIRONMENTOUTPUT']._serialized_end=526
  _globals['_DESCRIBECERTIFICATIONINPUT']._serialized_start=528
  _globals['_DESCRIBECERTIFICATIONINPUT']._serialized_end=576
  _globals['_DESCRIBECERTIFICATIONOUTPUT']._serialized_start=578
  _globals['_DESCRIBECERTIFICATIONOUTPUT']._serialized_end=659
  _globals['_CONFIGURECERTIFICATIONINPUT']._serialized_start=661
  _globals['_CONFIGURECERTIFICATIONINPUT']._serialized_end=762
  _globals['_CONFIGURECERTIFICATIONOUTPUT']._serialized_start=764
  _globals['_CONFIGURECERTIFICATIONOUTPUT']._serialized_end=794
  _globals['_DESCRIBETAXONOMYINPUT']._serialized_start=796
  _globals['_DESCRIBETAXONOMYINPUT']._serialized_end=839
  _globals['_DESCRIBETAXONOMYOUTPUT']._serialized_start=841
  _globals['_DESCRIBETAXONOMYOUTPUT']._serialized_end=907
  _globals['_CONFIGURETAXONOMYINPUT']._serialized_start=909
  _globals['_CONFIGURETAXONOMYINPUT']._serialized_end=995
  _globals['_CONFIGURETAXONOMYOUTPUT']._serialized_start=997
  _globals['_CONFIGURETAXONOMYOUTPUT']._serialized_end=1022
  _globals['_CONFIGURATIONSERVICE']._serialized_start=1025
  _globals['_CONFIGURATIONSERVICE']._serialized_end=2194
# @@protoc_insertion_point(module_scope)



from eolymp.runtime import runtime_pb2 as _runtime_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Environment(_message.Message):
    __slots__ = ("runtimes",)
    RUNTIMES_FIELD_NUMBER: _ClassVar[int]
    runtimes: _containers.RepeatedCompositeFieldContainer[_runtime_pb2.Runtime]
    def __init__(self, runtimes: _Optional[_Iterable[_Union[_runtime_pb2.Runtime, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/problem_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/atlas/problem_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import version_pb2 as eolymp_dot_atlas_dot_version__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/problem_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1a\x65olymp/atlas/version.proto\x1a\x1c\x65olymp/runtime/runtime.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x8a\x01\n\x13ProblemChangedEvent\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12&\n\x07version\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Version\"h\n\x12\x43reateProblemInput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\")\n\x13\x43reateProblemOutput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"h\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.atlas.Problem.Extra\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\"\xa6\x06\n\x11ListProblemsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.atlas.ListProblemsInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.atlas.ListProblemsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.atlas.Problem.Extra\x1a\xd5\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08topic_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\nis_visible\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nis_private\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x06number\x18\x05 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x33\n\ndifficulty\x18\x06 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x30\n\x06status\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\t \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x37\n\ris_bookmarked\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"0\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06RECENT\x10\x01\x12\x0b\n\x07POPULAR\x10\x02\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Problem\"<\n\x15UpdateVisibilityInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07visible\x18\x02 \x01(\x08\"\x18\n\x16UpdateVisibilityOutput\"9\n\x12UpdatePrivacyInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07private\x18\x02 \x01(\x08\"\x15\n\x13UpdatePrivacyOutput\"\xf1\x01\n\x12UpdateProblemInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.atlas.UpdateProblemInput.Patch\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12&\n\x07problem\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Problem\"h\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07VISIBLE\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x12\n\n\x06TOPICS\x10\x03\x12\x0e\n\nDIFFICULTY\x10\x04\x12\n\n\x06ORIGIN\x10\x05\x12\x08\n\x04TYPE\x10\x06\x12\n\n\x06NUMBER\x10\x07\"\x15\n\x13UpdateProblemOutput\"&\n\x10SyncProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x13\n\x11SyncProblemOutput\"\xa6\x03\n\x11ListVersionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.atlas.ListVersionsInput.Filter\x1a\x96\x02\n\x06\x46ilter\x12/\n\x06number\x18\x01 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x32\n\ncreated_by\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x39\n\ncreated_at\x18\x03 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tchange_op\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x37\n\x0b\x63hange_path\x18\x05 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"c\n\x12ListVersionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Version\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"4\n\x10VoteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"\'\n\x11VoteProblemOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"\'\n\x11ListRuntimesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"K\n\x12ListRuntimesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime\"9\n\x12\x45xportProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"+\n\x13\x45xportProblemOutput\x12\x14\n\x0csnapshot_url\x18\x01 \x01(\t2\xc2\x0c\n\x0eProblemService\x12\x91\x01\n\rCreateProblem\x12 .eolymp.atlas.CreateProblemInput\x1a!.eolymp.atlas.CreateProblemOutput\";\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\"\t/problems\x12\x9e\x01\n\rUpdateProblem\x12 .eolymp.atlas.UpdateProblemInput\x1a!.eolymp.atlas.UpdateProblemOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/problems/{problem_id}\x12\x9e\x01\n\rDeleteProblem\x12 .eolymp.atlas.DeleteProblemInput\x1a!.eolymp.atlas.DeleteProblemOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18*\x16/problems/{problem_id}\x12\xa3\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.atlas.DescribeProblemInput\x1a#.eolymp.atlas.DescribeProblemOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x18\x12\x16/problems/{problem_id}\x12\x8d\x01\n\x0cListProblems\x12\x1f.eolymp.atlas.ListProblemsInput\x1a .eolymp.atlas.ListProblemsOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0b\x12\t/problems\x12\x9d\x01\n\x0bSyncProblem\x12\x1e.eolymp.atlas.SyncProblemInput\x1a\x1f.eolymp.atlas.SyncProblemOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/problems/{problem_id}/sync\x12\x9d\x01\n\x0bVoteProblem\x12\x1e.eolymp.atlas.VoteProblemInput\x1a\x1f.eolymp.atlas.VoteProblemOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/problems/{problem_id}/vote\x12\x95\x01\n\x0cListVersions\x12\x1f.eolymp.atlas.ListVersionsInput\x1a .eolymp.atlas.ListVersionsOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/versions\x12\xa2\x01\n\x0cListRuntimes\x12\x1f.eolymp.atlas.ListRuntimesInput\x1a .eolymp.atlas.ListRuntimesOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x19\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02 \x12\x1e/problems/{problem_id}/runtime\x12\xa6\x01\n\rExportProblem\x12 .eolymp.atlas.ExportProblemInput\x1a!.eolymp.atlas.ExportProblemOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/snapshotB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateProblem']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\"\t/problems'
  _globals['_PROBLEMSERVICE'].methods_by_name['UpdateProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['UpdateProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030\032\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['DeleteProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DeleteProblem']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030*\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\030\022\026/problems/{problem_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListProblems']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListProblems']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\013\022\t/problems'
  _globals['_PROBLEMSERVICE'].methods_by_name['SyncProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['SyncProblem']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\035\"\033/problems/{problem_id}/sync'
  _globals['_PROBLEMSERVICE'].methods_by_name['VoteProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['VoteProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\035\"\033/problems/{problem_id}/vote'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListVersions']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListVersions']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002!\022\037/problems/{problem_id}/versions'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\031\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002 \022\036/problems/{problem_id}/runtime'
  _globals['_PROBLEMSERVICE'].methods_by_name['ExportProblem']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ExportProblem']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002!\022\037/problems/{problem_id}/snapshot'
  _globals['_PROBLEMCHANGEDEVENT']._serialized_start=337
  _globals['_PROBLEMCHANGEDEVENT']._serialized_end=475
  _globals['_CREATEPROBLEMINPUT']._serialized_start=477
  _globals['_CREATEPROBLEMINPUT']._serialized_end=581
  _globals['_CREATEPROBLEMOUTPUT']._serialized_start=583
  _globals['_CREATEPROBLEMOUTPUT']._serialized_end=624
  _globals['_DELETEPROBLEMINPUT']._serialized_start=626
  _globals['_DELETEPROBLEMINPUT']._serialized_end=666
  _globals['_DELETEPROBLEMOUTPUT']._serialized_start=668
  _globals['_DELETEPROBLEMOUTPUT']._serialized_end=689
  _globals['_DESCRIBEPROBLEMINPUT']._serialized_start=691
  _globals['_DESCRIBEPROBLEMINPUT']._serialized_end=795
  _globals['_DESCRIBEPROBLEMOUTPUT']._serialized_start=797
  _globals['_DESCRIBEPROBLEMOUTPUT']._serialized_end=860
  _globals['_LISTPROBLEMSINPUT']._serialized_start=863
  _globals['_LISTPROBLEMSINPUT']._serialized_end=1669
  _globals['_LISTPROBLEMSINPUT_FILTER']._serialized_start=1150
  _globals['_LISTPROBLEMSINPUT_FILTER']._serialized_end=1619
  _globals['_LISTPROBLEMSINPUT_SORTABLE']._serialized_start=1621
  _globals['_LISTPROBLEMSINPUT_SORTABLE']._serialized_end=1669
  _globals['_LISTPROBLEMSOUTPUT']._serialized_start=1671
  _globals['_LISTPROBLEMSOUTPUT']._serialized_end=1744
  _globals['_UPDATEVISIBILITYINPUT']._serialized_start=1746
  _globals['_UPDATEVISIBILITYINPUT']._serialized_end=1806
  _globals['_UPDATEVISIBILITYOUTPUT']._serialized_start=1808
  _globals['_UPDATEVISIBILITYOUTPUT']._serialized_end=1832
  _globals['_UPDATEPRIVACYINPUT']._serialized_start=1834
  _globals['_UPDATEPRIVACYINPUT']._serialized_end=1891
  _globals['_UPDATEPRIVACYOUTPUT']._serialized_start=1893
  _globals['_UPDATEPRIVACYOUTPUT']._serialized_end=1914
  _globals['_UPDATEPROBLEMINPUT']._serialized_start=1917
  _globals['_UPDATEPROBLEMINPUT']._serialized_end=2158
  _globals['_UPDATEPROBLEMINPUT_PATCH']._serialized_start=2054
  _globals['_UPDATEPROBLEMINPUT_PATCH']._serialized_end=2158
  _globals['_UPDATEPROBLEMOUTPUT']._serialized_start=2160
  _globals['_UPDATEPROBLEMOUTPUT']._serialized_end=2181
  _globals['_SYNCPROBLEMINPUT']._serialized_start=2183
  _globals['_SYNCPROBLEMINPUT']._serialized_end=2221
  _globals['_SYNCPROBLEMOUTPUT']._serialized_start=2223
  _globals['_SYNCPROBLEMOUTPUT']._serialized_end=2242
  _globals['_LISTVERSIONSINPUT']._serialized_start=2245
  _globals['_LISTVERSIONSINPUT']._serialized_end=2667
  _globals['_LISTVERSIONSINPUT_FILTER']._serialized_start=2389
  _globals['_LISTVERSIONSINPUT_FILTER']._serialized_end=2667
  _globals['_LISTVERSIONSOUTPUT']._serialized_start=2669
  _globals['_LISTVERSIONSOUTPUT']._serialized_end=2768
  _globals['_VOTEPROBLEMINPUT']._serialized_start=2770
  _globals['_VOTEPROBLEMINPUT']._serialized_end=2822
  _globals['_VOTEPROBLEMOUTPUT']._serialized_start=2824
  _globals['_VOTEPROBLEMOUTPUT']._serialized_end=2863
  _globals['_LISTRUNTIMESINPUT']._serialized_start=2865
  _globals['_LISTRUNTIMESINPUT']._serialized_end=2904
  _globals['_LISTRUNTIMESOUTPUT']._serialized_start=2906
  _globals['_LISTRUNTIMESOUTPUT']._serialized_end=2981
  _globals['_EXPORTPROBLEMINPUT']._serialized_start=2983
  _globals['_EXPORTPROBLEMINPUT']._serialized_end=3040
  _globals['_EXPORTPROBLEMOUTPUT']._serialized_start=3042
  _globals['_EXPORTPROBLEMOUTPUT']._serialized_end=3085
  _globals['_PROBLEMSERVICE']._serialized_start=3088
  _globals['_PROBLEMSERVICE']._serialized_end=4690
# @@protoc_insertion_point(module_scope)
